==> wls-plugin-3.0.1-sources.jar: com/xebialabs/deployit/plugin/wls/step/CreateWlsJmsDistributedQueueStep.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsDistributedQueue;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsQueue;
import com.xebialabs.deployit.plugin.wls.step.SimpleWlstExecutingStep;

/**
 * Creates a {@link WlsJmsDistributedQueue}.
 */
@SuppressWarnings("serial")
public class CreateWlsJmsDistributedQueueStep extends SimpleWlstExecutingStep {
	private static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-jms-distributed-queue.py";

	public CreateWlsJmsDistributedQueueStep(WlsDomain domain, String jmsModuleName, WlsJmsDistributedQueue queue) {
		super("Create JMS Distributed Queue " + queue + " in module " + jmsModuleName + " in domain " + domain, domain, SCRIPT_RESOURCE_PATH, 
				getArgs(queue, jmsModuleName));
	}

	private static String[] getArgs(WlsJmsDistributedQueue queue, String jmsModuleName) {
		List<String> args = new ArrayList<String>();
		args.add(jmsModuleName);
		args.add(queue.getName());
		args.add(queue.getJndiName());
		args.add(queue.getLoadBalancingPolicy().getValue());
		args.add(String.valueOf((queue.getForwardDelay() == 0) ? -1 : queue.getForwardDelay()));
		args.add(String.valueOf(queue.getMembers().size()));
		for (WlsJmsQueue member : queue.getMembers()) {
			args.add(member.getName());
		}
		return args.toArray(new String[args.size()]);
	}

}

==> wls-plugin-3.0.2-sources.jar: com/xebialabs/deployit/plugin/wls/step/CreateWlsJmsDistributedQueueStep.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import java.awt.*;
import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.hostsession.CmdLineArgument;
import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsDistributedQueue;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsQueue;
import com.xebialabs.deployit.plugin.wls.step.SimpleWlstExecutingStep;

/**
 * Creates a {@link WlsJmsDistributedQueue}.
 */
@SuppressWarnings("serial")
public class CreateWlsJmsDistributedQueueStep extends SimpleWlstExecutingStep {
	private static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-jms-distributed-queue.py";

	public CreateWlsJmsDistributedQueueStep(WlsDomain domain, String jmsModuleName, WlsJmsDistributedQueue queue) {
		super("Create JMS Distributed Queue " + queue + " in module " + jmsModuleName + " in domain " + domain, domain, SCRIPT_RESOURCE_PATH, 
				getArgs(queue, jmsModuleName));
	}

	private static List<CmdLineArgument> getArgs(WlsJmsDistributedQueue queue, String jmsModuleName) {
		List<CmdLineArgument> args = new ArrayList<CmdLineArgument>();
		args.add(CmdLineArgument.arg(jmsModuleName));
		args.add(CmdLineArgument.arg(queue.getName()));
		args.add(CmdLineArgument.arg(queue.getJndiName()));
		args.add(CmdLineArgument.arg(queue.getLoadBalancingPolicy().getValue()));
		args.add(CmdLineArgument.arg(String.valueOf((queue.getForwardDelay() == 0) ? -1 : queue.getForwardDelay())));
		args.add(CmdLineArgument.arg(String.valueOf(queue.getMembers().size())));
		for (WlsJmsQueue member : queue.getMembers()) {
			args.add(CmdLineArgument.arg(member.getName()));
		}
		return args;
	}

}
